Old module which contained some implementation details of the #[pyproto] module.
Prefer using the same content from pyforge::pyclass, e.g. use pyforge::pyclass::PyTraverseError instead
of use pyforge::class::gc::PyTraverseError.
For compatibility reasons this has not yet been removed, however will be done so once https://github.com/rust-lang/rust/issues/30827 is resolved.
Re-exports
pub use crate::pyclass::PyTraverseError;pub use crate::pyclass::PyVisit;